# NC State Authentication Package

This package is meant to make authenticating users for PHP web applications at NC State
easier to manage.

## Goals

* Standardize authentication interface for several on-campus providers.
* Provide extensible authentication framework to allow for custom integrations.

## Install

Add this to your `composer.json` file

``` json
{
    "repositories": [
        {
            "type": "composer",
            "url": "http://www.webtools.ncsu.edu/packages"
        }
    ]
}
```

Then install the package

```
> composer require ncsu/auth
```

## Requirements

The following versions of PHP are supported by this version.

* PHP 5.6

## Documentation

**Usage in a plain ol' PHP script**

``` php
// Example of WRAP Authentication

<?php

require_once('../vendor/autoload.php');

use NCSU\Auth\Adapter\WrapAuthAdapter;
use NCSU\Auth\AuthService;
use NCSU\Auth\Http\Request;

$request = Request::createFromGlobals();

$wrapAuthAdapter = new WrapAuthAdapter($request);
$service = new AuthService($wrapAuthAdapter);

$result = $service->authenticate();

if ($result->isValid()) {
    echo sprintf("Your authentication request as %s was successful!", $result->getIdentity());
} else {
    echo "Failed to authenticate!";
}
```

**Laravel**

Open `app/Http/Kernel.php` and register the package middleware as a global, grouped, or route middleware by your own name.

``` php
/**
 * The application's route middleware.
 *
 * These middleware may be assigned to groups or used individually.
 *
 * @var array
 */
protected $routeMiddleware = [
    // --
    'auth.shib' => \NCSU\Auth\Framework\Laravel\ShibbolethAuthenticate::class,
    // --
];
```

## Testing

``` bash
$ phpunit
```

## Contributing

Contributions are **welcome** and will be fully **credited**.

We accept contributions via Pull Requests on [Github](https://github.ncsu.edu/ncstate-contrib/auth).

## Pull Requests

- **[PSR-2 Coding Standard](https://github.com/php-fig/fig-standards/blob/master/accepted/PSR-2-coding-style-guide.md)** - The easiest way to apply the conventions is to install [PHP Code Sniffer](http://pear.php.net/package/PHP_CodeSniffer).

- **Add tests!** - Your patch won't be accepted if it doesn't have tests.

- **Document any change in behaviour** - Make sure the README and any other relevant documentation are kept up-to-date.

- **Consider our release cycle** - We try to follow semver. Randomly breaking public APIs is not an option.

- **Create topic branches** - Don't ask us to pull from your master branch.

- **One pull request per feature** - If you want to do more than one thing, send multiple pull requests.

- **Send coherent history** - Make sure each individual commit in your pull request is meaningful. If you had to make multiple intermediate commits while developing, please squash them before submitting.

## Running Tests

``` bash
$ phpunit
```

**Happy coding**!

## License

The MIT License (MIT). Please see [License File](./LICENSE) for more information.
