<?php
  /**
 * This file is part of a project maintained at  NC State University.
 *
 * More information is included in the project README.md.
 *
 * (c) NC State University
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace NCSU\Auth\Tests;

use NCSU\Auth\AuthResult;

class AuthResultTest extends \PHPUnit_Framework_TestCase
{
    /** @test */
    function it_works()
    {
        $result = new AuthResult(AuthResult::FAILURE, '', [
            'foo', 'bar', 'baz'
        ]);

        $this->assertFalse($result->isValid());
        $this->assertEquals(AuthResult::FAILURE, $result->getCode());
        $this->assertEquals('', $result->getIdentity());
        $this->assertContains('foo', $result->getMessages());
    }

    /** @test */
    function it_squawks_if_auth_is_successful_but_identity_is_empty()
    {
        $this->setExpectedException('NCSU\Auth\Exception\InvalidArgumentException');

        $result = new AuthResult(AuthResult::SUCCESS, '');
    }

    /** @test */
    function it_squawks_if_auth_is_successful_but_error_messages_are_provided()
    {
        $this->setExpectedException('NCSU\Auth\Exception\InvalidArgumentException');

        $result = new AuthResult(AuthResult::SUCCESS, 'authuser', array('foo', 'bar'));
    }

}
 